/*jshint esversion:6*/

var shell = require("gulp-shell");
var release = require("gulp-release-it");
var fsp = require("fs-promise");
var ejs = require("ejs");
var _ = require('underscore');

var TEMPLATE = ejs.compile( `# auto generated setup.py script - please don't edit directly!
from setuptools import setup

setup(
    name = '<%= name %>',
    version = '<%= version %>',
    description = '<%= description %>',
    author_email = '<%= author %>',
    license = '<%= license %>',
    keywords = '<%= keywords.join( " " ) %>',
    packages = [ '<%= name %>' ]
)
`);

var DEFAULTS = {
    license : "MIT",
    author : "",
    description : "",
    keywords : []
};

module.exports = function( gulp ) {

    release(gulp);

    gulp.task( "mk-setup", [ "release" ], function( cb ) {
        // load a fresh version of the node package json file
        fsp.readFile( "package.json" )
            .then( function(data) {
                var pkg = _.extend( {}, DEFAULTS, JSON.parse( data ) );
                var templated = TEMPLATE( pkg );
                return fsp.writeFile( "setup.py", templated );
            })
            .then( () => cb(null) );
    });

    gulp.task( "py-release", [ "mk-setup" ], shell.task([
        "mkdir -p dist",
        "rm -f dist/*",
        "python setup.py register",
        "python setup.py sdist",
        "twine upload dist/*"
    ]));

};
